@@ -51,7 +51,6 @@ class ShareMixin(object):
     def _delete(self, *args, **kwargs):
         return self.share_api.delete(*args, **kwargs)
 
-    @wsgi.Controller.authorize('get')
     def show(self, req, id):
         """Return data about the given share."""
         context = req.environ['manila.context']
@@ -63,7 +62,6 @@ class ShareMixin(object):
 
         return self._view_builder.detail(req, share)
 
-    @wsgi.Controller.authorize
     def delete(self, req, id):
         """Delete a share."""
         context = req.environ['manila.context']
@@ -98,7 +96,6 @@ class ShareMixin(object):
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
-    @wsgi.Controller.authorize("get_all")
     def index(self, req):
         """Returns a summary list of shares."""
         req.GET.pop('export_location_id', None)
@@ -109,7 +106,6 @@ class ShareMixin(object):
         req.GET.pop('with_count', None)
         return self._get_shares(req, is_detail=False)
 
-    @wsgi.Controller.authorize("get_all")
     def detail(self, req):
         """Returns a detailed list of shares."""
         req.GET.pop('export_location_id', None)
@@ -392,8 +388,6 @@ class ShareMixin(object):
                     exception.ShareTypeNotFoundByName):
                 msg = _("Share type not found.")
                 raise exc.HTTPNotFound(explanation=msg)
-            except exception.InvalidShareType as e:
-                raise exc.HTTPBadRequest(explanation=e.message)
         elif not snapshot:
             def_share_type = share_types.get_default_share_type()
             if def_share_type:
@@ -456,7 +450,7 @@ class ShareMixin(object):
     @wsgi.Controller.authorize('allow_access')
     def _allow_access(self, req, id, body, enable_ceph=False,
                       allow_on_error_status=False, enable_ipv6=False,
-                      enable_metadata=False):
+                      enable_metadata=False, allow_on_error_state=False):
         """Add share access rule."""
         context = req.environ['manila.context']
         access_data = body.get('allow_access', body.get('os-allow_access'))
@@ -494,7 +488,8 @@ class ShareMixin(object):
         try:
             access = self.share_api.allow_access(
                 context, share, access_type, access_to,
-                access_data.get('access_level'), access_data.get('metadata'))
+                access_data.get('access_level'), access_data.get('metadata'),
+                allow_on_error_state)
         except exception.ShareAccessExists as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
 
@@ -507,7 +502,7 @@ class ShareMixin(object):
         return self._access_view_builder.view(req, access)
 
     @wsgi.Controller.authorize('deny_access')
-    def _deny_access(self, req, id, body):
+    def _deny_access(self, req, id, body, allow_on_error_state=False):
         """Remove share access rule."""
         context = req.environ['manila.context']
 
@@ -534,7 +529,8 @@ class ShareMixin(object):
             share = self.share_api.get(context, id)
         except exception.NotFound as error:
             raise webob.exc.HTTPNotFound(explanation=error.message)
-        self.share_api.deny_access(context, share, access)
+        self.share_api.deny_access(context, share, access,
+                                   allow_on_error_state)
         return webob.Response(status_int=http_client.ACCEPTED)
 
     def _access_list(self, req, id, body):
@@ -546,7 +542,6 @@ class ShareMixin(object):
 
         return self._access_view_builder.list_view(req, access_rules)
 
-    @wsgi.Controller.authorize("extend")
     def _extend(self, req, id, body):
         """Extend size of a share."""
         context = req.environ['manila.context']
@@ -567,7 +562,6 @@ class ShareMixin(object):
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
-    @wsgi.Controller.authorize("shrink")
     def _shrink(self, req, id, body):
         """Shrink size of a share."""
         context = req.environ['manila.context']
