@@ -231,27 +231,26 @@ class ShareController(wsgi.Controller,
         try:
             share = self.share_api.get(context, id)
         except exception.NotFound:
-            raise exc.HTTPNotFound("Share %s not found" % id)
+            raise exception.ShareNotFound(share_id=id)
         if share.get('is_soft_deleted'):
             msg = _("status cannot be reset for share '%s' "
                     "since it has been soft deleted.") % id
             raise exc.HTTPForbidden(explanation=msg)
-        return self._reset_status(req, id, body, resource=share)
+        return self._reset_status(req, id, body)
 
     @wsgi.Controller.api_version('2.7')
     @wsgi.action('reset_status')
-    @wsgi.Controller.authorize('reset_status')
     def share_reset_status(self, req, id, body):
         context = req.environ['manila.context']
         try:
             share = self.share_api.get(context, id)
         except exception.NotFound:
-            raise exc.HTTPNotFound("Share %s not found" % id)
+            raise exception.ShareNotFound(share_id=id)
         if share.get('is_soft_deleted'):
             msg = _("status cannot be reset for share '%s' "
                     "since it has been soft deleted.") % id
             raise exc.HTTPForbidden(explanation=msg)
-        return self._reset_status(req, id, body, resource=share)
+        return self._reset_status(req, id, body)
 
     @wsgi.Controller.api_version('2.0', '2.6')
     @wsgi.action('os-force_delete')
@@ -265,7 +264,6 @@ class ShareController(wsgi.Controller,
 
     @wsgi.Controller.api_version('2.69')
     @wsgi.action('soft_delete')
-    @wsgi.Controller.authorize('soft_delete')
     def share_soft_delete(self, req, id, body):
         """Soft delete a share."""
         context = req.environ['manila.context']
@@ -288,7 +286,6 @@ class ShareController(wsgi.Controller,
 
     @wsgi.Controller.api_version('2.69')
     @wsgi.action('restore')
-    @wsgi.Controller.authorize("restore")
     def share_restore(self, req, id, body):
         """Restore a share from recycle bin."""
         context = req.environ['manila.context']
@@ -453,8 +450,7 @@ class ShareController(wsgi.Controller,
             msg = _("task state cannot be reset for share '%s' "
                     "since it has been soft deleted.") % id
             raise exc.HTTPForbidden(explanation=msg)
-        return self._reset_status(req, id, body, status_attr='task_state',
-                                  resource=share)
+        return self._reset_status(req, id, body, status_attr='task_state')
 
     @wsgi.Controller.api_version('2.0', '2.6')
     @wsgi.action('os-allow_access')
@@ -476,6 +472,8 @@ class ShareController(wsgi.Controller,
             kwargs['enable_ipv6'] = True
         if req.api_version_request >= api_version.APIVersionRequest("2.45"):
             kwargs['enable_metadata'] = True
+        if req.api_version_request >= api_version.APIVersionRequest("2.74"):
+            kwargs['allow_on_error_state'] = True
         return self._allow_access(*args, **kwargs)
 
     @wsgi.Controller.api_version('2.0', '2.6')
@@ -488,7 +486,11 @@ class ShareController(wsgi.Controller,
     @wsgi.action('deny_access')
     def deny_access(self, req, id, body):
         """Remove share access rule."""
-        return self._deny_access(req, id, body)
+        args = (req, id, body)
+        kwargs = {}
+        if req.api_version_request >= api_version.APIVersionRequest("2.74"):
+            kwargs['allow_on_error_state'] = True
+        return self._deny_access(*args, **kwargs)
 
     @wsgi.Controller.api_version('2.0', '2.6')
     @wsgi.action('os-access_list')
@@ -567,7 +569,6 @@ class ShareController(wsgi.Controller,
         return self._revert(req, id, body)
 
     @wsgi.Controller.api_version("2.0")
-    @wsgi.Controller.authorize("get_all")
     def index(self, req):
         """Returns a summary list of shares."""
         if req.api_version_request < api_version.APIVersionRequest("2.35"):
@@ -588,7 +589,6 @@ class ShareController(wsgi.Controller,
         return self._get_shares(req, is_detail=False)
 
     @wsgi.Controller.api_version("2.0")
-    @wsgi.Controller.authorize("get_all")
     def detail(self, req):
         """Returns a detailed list of shares."""
         if req.api_version_request < api_version.APIVersionRequest("2.35"):
