@@ -20,12 +20,14 @@
 import copy
 
 from oslo_context import context
+from oslo_db.sqlalchemy import enginefacade
 from oslo_utils import timeutils
 
 from manila.i18n import _
 from manila import policy
 
 
+@enginefacade.transaction_context_provider
 class RequestContext(context.RequestContext):
     """Security context and request information.
 
@@ -106,7 +108,7 @@ class RequestContext(context.RequestContext):
             project_id=values.get('project_id'),
             project_name=values.get('project_name'),
             domain_id=values.get('domain_id'),
-            read_deleted=values.get('read_deleted', 'no'),
+            read_deleted=values.get('read_deleted'),
             remote_address=values.get('remote_address'),
             timestamp=values.get('timestamp'),
             quota_class=values.get('quota_class'),
