@@ -63,6 +63,7 @@ class Service(BASE, ManilaBase):
     host = Column(String(255))  # , ForeignKey('hosts.id'))
     binary = Column(String(255))
     topic = Column(String(255))
+    state = Column(String(36))
     report_count = Column(Integer, nullable=False, default=0)
     disabled = Column(Boolean, default=False)
     availability_zone_id = Column(String(36),
@@ -736,6 +737,24 @@ class ShareSnapshot(BASE, ManilaBase):
                              'ShareSnapshot.deleted == "False")')
 
 
+class ShareSnapshotMetadata(BASE, ManilaBase):
+    """Represents a metadata key/value pair for a snapshot."""
+    __tablename__ = 'share_snapshot_metadata'
+    id = Column(Integer, primary_key=True)
+    key = Column(String(255), nullable=False)
+    value = Column(String(1023), nullable=False)
+    deleted = Column(String(36), default='False')
+    share_snapshot_id = Column(String(36), ForeignKey(
+        'share_snapshots.id'), nullable=False)
+
+    share_snapshot = orm.relationship(
+        ShareSnapshot, backref="share_snapshot_metadata",
+        foreign_keys=share_snapshot_id,
+        primaryjoin='and_('
+        'ShareSnapshotMetadata.share_snapshot_id == ShareSnapshot.id,'
+        'ShareSnapshotMetadata.deleted == "False")')
+
+
 class ShareSnapshotInstance(BASE, ManilaBase):
     """Represents a snapshot of a share."""
     __tablename__ = 'share_snapshot_instances'
@@ -913,6 +932,7 @@ class SecurityService(BASE, ManilaBase):
     name = Column(String(255), nullable=True)
     description = Column(String(255), nullable=True)
     ou = Column(String(255), nullable=True)
+    default_ad_site = Column(String(255), nullable=True)
 
 
 class ShareNetwork(BASE, ManilaBase):
@@ -982,7 +1002,7 @@ class ShareNetwork(BASE, ManilaBase):
 class ShareNetworkSubnet(BASE, ManilaBase):
     """Represents a share network subnet used by some resources."""
 
-    _extra_keys = ['availability_zone']
+    _extra_keys = ['availability_zone', 'subnet_metadata']
 
     __tablename__ = 'share_network_subnets'
     id = Column(String(36), primary_key=True, nullable=False)
@@ -1037,6 +1057,35 @@ class ShareNetworkSubnet(BASE, ManilaBase):
     def share_network_name(self):
         return self.share_network['name']
 
+    @property
+    def subnet_metadata(self):
+        metadata_dict = {}
+        metadata_list = (
+            self.share_network_subnet_metadata)  # pylint: disable=no-member
+        for meta in metadata_list:
+            metadata_dict[meta['key']] = meta['value']
+        return metadata_dict
+
+
+class ShareNetworkSubnetMetadata(BASE, ManilaBase):
+    """Represents a metadata key/value pair for a subnet."""
+    __tablename__ = 'share_network_subnet_metadata'
+    id = Column(Integer, primary_key=True)
+    key = Column(String(255), nullable=False)
+    value = Column(String(1023), nullable=False)
+    deleted = Column(String(36), default='False')
+    share_network_subnet_id = Column(String(36), ForeignKey(
+        'share_network_subnets.id'), nullable=False)
+
+    share_network_subnet = orm.relationship(
+        ShareNetworkSubnet,
+        backref=orm.backref('share_network_subnet_metadata', lazy='immediate'),
+        foreign_keys=share_network_subnet_id,
+        primaryjoin='and_('
+        'ShareNetworkSubnetMetadata.share_network_subnet_id == '
+        'ShareNetworkSubnet.id,'
+        'ShareNetworkSubnetMetadata.deleted == "False")')
+
 
 class ShareServer(BASE, ManilaBase):
     """Represents share server used by share."""
@@ -1151,6 +1200,26 @@ class ShareNetworkSecurityServiceAssociation(BASE, ManilaBase):
                                  nullable=False)
 
 
+class Transfer(BASE, ManilaBase):
+    """Represents a share transfer request."""
+
+    __tablename__ = 'transfers'
+
+    id = Column(String(36), primary_key=True, nullable=False)
+    deleted = Column(String(36), default='False')
+    # resource type can be "share" or "share_network"
+    resource_type = Column(String(36), nullable=False)
+    # The uuid of the related resource.
+    resource_id = Column(String(36), nullable=False)
+    display_name = Column(String(255))
+    salt = Column(String(255))
+    crypt_hash = Column(String(255))
+    expires_at = Column(DateTime)
+    source_project_id = Column(String(255), nullable=True)
+    destination_project_id = Column(String(255), nullable=True)
+    accepted = Column(Boolean, default=False)
+
+
 class NetworkAllocation(BASE, ManilaBase):
     """Represents network allocation data."""
     __tablename__ = 'network_allocations'
@@ -1184,6 +1253,9 @@ class DriverPrivateData(BASE, ManilaBase):
 class AvailabilityZone(BASE, ManilaBase):
     """Represents a private data as key-value pairs for a driver."""
     __tablename__ = 'availability_zones'
+    __table_args__ = (
+        schema.UniqueConstraint('name', 'deleted', name='az_name_uc'),
+    )
     id = Column(String(36), primary_key=True, nullable=False)
     deleted = Column(String(36), default='False')
     name = Column(String(255), nullable=False)
