@@ -367,7 +367,8 @@ class CephFSDriverTestCase(test.TestCase):
         snapshot_create_dict = {
             "vol_name": self._driver.volname,
             "sub_name": self._snapshot["share_id"],
-            "snap_name": self._snapshot["snapshot_id"]
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
         }
 
         self._driver.create_snapshot(self._context, self._snapshot, None)
@@ -377,35 +378,23 @@ class CephFSDriverTestCase(test.TestCase):
             snapshot_create_prefix, snapshot_create_dict)
 
     def test_delete_snapshot(self):
-        legacy_snap_name = "_".join(
-            [self._snapshot["snapshot_id"], self._snapshot["id"]])
-
         snapshot_remove_prefix = "fs subvolume snapshot rm"
 
         snapshot_remove_dict = {
             "vol_name": self._driver.volname,
             "sub_name": self._snapshot["share_id"],
-            "snap_name": legacy_snap_name,
-            "force": True
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
+            "force": True,
         }
 
-        snapshot_remove_dict_2 = snapshot_remove_dict.copy()
-        snapshot_remove_dict_2.update(
-            {"snap_name": self._snapshot["snapshot_id"]})
-
         self._driver.delete_snapshot(self._context,
                                      self._snapshot,
                                      None)
 
-        driver.rados_command.assert_has_calls([
-            mock.call(self._driver.rados_client,
-                      snapshot_remove_prefix,
-                      snapshot_remove_dict),
-            mock.call(self._driver.rados_client,
-                      snapshot_remove_prefix,
-                      snapshot_remove_dict_2)])
-
-        self.assertEqual(2, driver.rados_command.call_count)
+        driver.rados_command.assert_called_once_with(
+            self._driver.rados_client,
+            snapshot_remove_prefix, snapshot_remove_dict)
 
     def test_create_share_group(self):
         group_create_prefix = "fs subvolumegroup create"
@@ -479,7 +468,8 @@ class CephFSDriverTestCase(test.TestCase):
         create_share_from_snapshot_dict = {
             "vol_name": self._driver.volname,
             "sub_name": parent_share["id"],
-            "snap_name": self._snapshot["snapshot_id"],
+            "snap_name": "_".join([
+                self._snapshot["snapshot_id"], self._snapshot["id"]]),
             "target_sub_name": self._share["id"]
         }
 
@@ -598,6 +588,26 @@ class CephFSDriverTestCase(test.TestCase):
         (self._driver.protocol_helper.get_configured_ip_versions.
             assert_called_once_with())
 
+    @ddt.data(
+        ([{'id': 'instance_mapping_id1', 'access_id': 'accessid1',
+           'access_level': 'rw', 'access_type': 'cephx', 'access_to': 'alice'
+           }], 'fake_project_uuid_1'),
+        ([{'id': 'instance_mapping_id1', 'access_id': 'accessid1',
+           'access_level': 'rw', 'access_type': 'cephx', 'access_to': 'alice'
+           }], 'fake_project_uuid_2'),
+        ([], 'fake_project_uuid_1'),
+        ([], 'fake_project_uuid_2'),
+    )
+    @ddt.unpack
+    def test_transfer_accept(self, access_rules, new_project):
+        fake_share_1 = {"project_id": "fake_project_uuid_1"}
+        same_project = new_project == 'fake_project_uuid_1'
+        if access_rules and not same_project:
+            self.assertRaises(exception.DriverCannotTransferShareWithRules,
+                              self._driver.transfer_accept,
+                              self._context, fake_share_1,
+                              'new_user', new_project, access_rules)
+
 
 @ddt.ddt
 class NativeProtocolHelperTestCase(test.TestCase):
